@@ -1,17 +1,17 @@
 package WWW::Correios::SRO;
-
 use strict;
 use warnings;
 
 use parent 'Exporter';
 our @EXPORT_OK = qw( sro sro_en sro_ok sro_sigla status_da_entrega );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 my $AGENT = 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)';
 my $TIMEOUT = 30;
 
-# Verificado em 22 de Maio de 2017
-# http://www.correios.com.br/para-voce/precisa-de-ajuda/como-rastrear-um-objeto/siglas-utilizadas-no-rastreamento-de-objeto
+# Verificado em 6 de Abril de 2018
+# https://www.correios.com.br/precisa-de-ajuda/como-rastrear-um-objeto/siglas-utilizadas-no-rastreamento-de-objeto
+# (era http://www.correios.com.br/para-voce/precisa-de-ajuda/como-rastrear-um-objeto/siglas-utilizadas-no-rastreamento-de-objeto)
 #
 #
 # Sabemos que as seguintes siglas são usadas: DH
@@ -23,239 +23,268 @@ my $TIMEOUT = 30;
 my %siglas = (
   AL => 'AGENTES DE LEITURA',
   AR => 'AVISO DE RECEBIMENTO',
-  AS => 'ENCOMENDA PAC – AÇÃO SOCIAL',
-  BE => 'REMESSA ECONÔMICA TALÃO/CARTÃO (SEM AR DIGITAL)',
-  CA => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CB => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CC => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CD => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CE => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CF => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CG => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CH => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CI => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CJ => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CK => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CL => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CM => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CN => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CO => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CP => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CQ => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CR => 'CARTA REGISTRADA SEM VALOR DECLARADO',
-  CS => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CT => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CU => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CV => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CW => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CX => 'ENCOMENDA INTERNACIONAL - COLIS OU SELO LACRE PARA CAIXETAS',
-  CY => 'ENCOMENDA INTERNACIONAL - COLIS',
-  CZ => 'ENCOMENDA INTERNACIONAL - COLIS',
-  DA => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL',
-  DB => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL (BRADESCO)',
-  DC => 'REMESSA EXPRESSA CRLV/CRV/CNH e NOTIFICAÇÕES',
-  DD => 'DEVOLUÇÃO DE DOCUMENTOS',
-  DE => 'REMESSA EXPRESSA TALÃO/CARTÃO COM AR',
-  DF => 'E-SEDEX',
-  DG => 'SEDEX',
-  DI => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL (ITAU)',
-  DJ => 'SEDEX',
-  DK => 'PAC EXTRA GRANDE',
-  DL => 'SEDEX',
-  DM => 'E-SEDEX',
-  DN => 'SEDEX',
-  DO => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL (ITAU)',
+  AS => 'ENCOMENDA PAC – ACAO SOCIAL',
+  BE => 'REMESSA ECONOMICA SEM AR DIGITAL',
+  BF => 'REMESSA EXPRESSA SEM AR DIGITAL',
+  BG => 'ETIQUETA LOG REM ECON C/AR BG',
+  BH => 'MENSAGEM FISICO-DIGITAL',
+  BI => 'ETIQUETA LOG REGIST URG',
+  CA => 'OBJETO INTERNACIONAL COLIS',
+  CB => 'OBJETO INTERNACIONAL COLIS',
+  CC => 'OBJETO INTERNACIONAL COLIS',
+  CD => 'OBJETO INTERNACIONAL COLIS',
+  CE => 'OBJETO INTERNACIONAL COLIS',
+  CF => 'OBJETO INTERNACIONAL COLIS',
+  CG => 'OBJETO INTERNACIONAL COLIS',
+  CH => 'OBJETO INTERNACIONAL COLIS',
+  CI => 'OBJETO INTERNACIONAL COLIS',
+  CJ => 'OBJETO INTERNACIONAL COLIS',
+  CK => 'OBJETO INTERNACIONAL COLIS',
+  CL => 'OBJETO INTERNACIONAL COLIS',
+  CM => 'OBJETO INTERNACIONAL COLIS',
+  CN => 'OBJETO INTERNACIONAL COLIS',
+  CO => 'OBJETO INTERNACIONAL COLIS',
+  CP => 'OBJETO INTERNACIONAL COLIS',
+  CQ => 'OBJETO INTERNACIONAL COLIS',
+  CR => 'OBJETO INTERNACIONAL COLIS',
+  CS => 'OBJETO INTERNACIONAL COLIS',
+  CT => 'OBJETO INTERNACIONAL COLIS',
+  CU => 'OBJETO INTERNACIONAL COLIS',
+  CV => 'OBJETO INTERNACIONAL COLIS',
+  CW => 'OBJETO INTERNACIONAL COLIS',
+  CX => 'OBJETO INTERNACIONAL COLIS',
+  CY => 'OBJETO INTERNACIONAL COLIS',
+  CZ => 'OBJETO INTERNACIONAL COLIS',
+  DA => 'ENCOMENDA SEDEX COM AR DIGITAL',
+  DB => 'REMESSA EXPRESSA COM AR DIGITAL (BRADESCO)',
+  DC => 'REMESSA EXPRESSA (ORGAO TRANSITO)',
+  DD => 'DEVOLUCAO DE DOCUMENTOS',
+  DE => 'REMESSA EXPRESSA COM AR DIGITAL',
+  DF => 'ENCOMENDA SEDEX (ETIQ LOGICA)',
+  DG => 'ENCOMENDA SEDEX (ETIQ LOGICA)',
+  DI => 'REMESSA EXPRESSA COM AR DIGITAL (ITAU)',
+  DJ => 'ENCOMENDA SEDEX',
+  DK => 'SEDEX EXTRA GRANDE',
+  DL => 'SEDEX LOGICO',
+  DM => 'ENCOMENDA SEDEX',
+  DN => 'ENCOMENDA SEDEX',
+  DO => 'REMESSA EXPRESSA COM AR DIGITAL (ITAU UNIBANCO)',
   DP => 'SEDEX PAGAMENTO NA ENTREGA',
-  DQ => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL (BRADESCO)',
+  DQ => 'REMESSA EXPRESSA COM AR DIGITAL (BRADESCO)',
   DR => 'REMESSA EXPRESSA COM AR DIGITAL (SANTANDER)',
-  DS => 'SEDEX OU REMESSA EXPRESSA COM AR DIGITAL (SANTANDER)',
-  DT => 'REMESSA ECONÔMICA COM AR DIGITAL (DETRAN)',
-  DU => 'E-SEDEX',
+  DS => 'REMESSA EXPRESSA COM AR DIGITAL (SANTANDER)',
+  DT => 'REMESSA ECON. SEG. TRANSITO COM AR DIGITAL',
+  DU => 'ENCOMENDA SEDEX',
   DV => 'SEDEX COM AR DIGITAL',
-  DW => 'ENCOMENDA SEDEX (ETIQUETA LÓGICA)',
-  DX => 'SEDEX 10',
-  EA => 'ENCOMENDA INTERNACIONAL - EMS',
-  EB => 'ENCOMENDA INTERNACIONAL - EMS',
-  EC => 'PAC',
-  ED => 'PACKET EXPRESS',
-  EE => 'ENCOMENDA INTERNACIONAL - EMS',
-  EF => 'ENCOMENDA INTERNACIONAL - EMS',
-  EG => 'ENCOMENDA INTERNACIONAL - EMS',
-  EH => 'ENCOMENDA INTERNACIONAL - EMS OU ENCOMENDA COM AR DIGITAL',
-  EI => 'ENCOMENDA INTERNACIONAL - EMS',
-  EJ => 'ENCOMENDA INTERNACIONAL - EMS',
-  EK => 'ENCOMENDA INTERNACIONAL - EMS',
-  EL => 'ENCOMENDA INTERNACIONAL - EMS',
-  EM => 'ENCOMENDA INTERNACIONAL - SEDEX MUNDI OU EMS IMPORTAÇÃO',
-  EN => 'ENCOMENDA INTERNACIONAL - EMS',
-  EO => 'ENCOMENDA INTERNACIONAL - EMS',
-  EP => 'ENCOMENDA INTERNACIONAL - EMS',
-  EQ => 'ENCOMENDA DE SERVIÇO NÃO EXPRESSA (ECT)',
-  ER => 'OBJETO REGISTRADO',
+  DW => 'ENCOMENDA SEDEX (ETIQ LOGICA)',
+  DX => 'SEDEX 10 LOGICO',
+  DY => 'ENCOMENDA SEDEX (ETIQ FISICA)',
+  DZ => 'ENCOMENDA SEDEX (ETIQ LOGICA)',
+  EA => 'OBJETO INTERNACIONAL EMS',
+  EB => 'OBJETO INTERNACIONAL EMS',
+  EC => 'ENCOMENDA PAC',
+  ED => 'OBJETO INTERNACIONAL PACKET EXPRESS',
+  EE => 'OBJETO INTERNACIONAL EMS',
+  EF => 'OBJETO INTERNACIONAL EMS',
+  EG => 'OBJETO INTERNACIONAL EMS',
+  EH => 'OBJETO INTERNACIONAL EMS',
+  EI => 'OBJETO INTERNACIONAL EMS',
+  EJ => 'OBJETO INTERNACIONAL EMS',
+  EK => 'OBJETO INTERNACIONAL EMS',
+  EL => 'OBJETO INTERNACIONAL EMS',
+  EM => 'SEDEX MUNDI',
+  EN => 'OBJETO INTERNACIONAL EMS',
+  EO => 'OBJETO INTERNACIONAL EMS',
+  EP => 'OBJETO INTERNACIONAL EMS',
+  EQ => 'ENCOMENDA SERVICO NAO EXPRESSA ECT',
+  ER => 'REGISTRADO',
   ES => 'E-SEDEX OU EMS',
-  ET => 'ENCOMENDA INTERNACIONAL - EMS',
-  EU => 'ENCOMENDA INTERNACIONAL - EMS',
-  EV => 'ENCOMENDA INTERNACIONAL - EMS',
-  EW => 'ENCOMENDA INTERNACIONAL - EMS',
-  EX => 'ENCOMENDA INTERNACIONAL - EMS',
-  EY => 'ENCOMENDA INTERNACIONAL - EMS',
-  EZ => 'ENCOMENDA INTERNACIONAL - EMS',
+  ET => 'OBJETO INTERNACIONAL EMS',
+  EU => 'OBJETO INTERNACIONAL EMS',
+  EV => 'OBJETO INTERNACIONAL EMS',
+  EW => 'OBJETO INTERNACIONAL EMS',
+  EX => 'OBJETO INTERNACIONAL EMS',
+  EY => 'OBJETO INTERNACIONAL EMS',
+  EZ => 'OBJETO INTERNACIONAL EMS',
   FA => 'FAC REGISTRADO',
+  FB => 'FAC REGISTRADO',
+  FC => 'FAC REGISTRADO (5 DIAS)',
+  FD => 'FAC REGISTRADO (10 DIAS)',
   FE => 'ENCOMENDA FNDE',
-  FF => 'OBJETO REGISTRADO (DETRAN)',
+  FF => 'REGISTRADO DETRAN',
   FH => 'FAC REGISTRADO COM AR DIGITAL',
-  FM => 'FAC MONITORADO',
+  FJ => 'REMESSA ECONOMICA COM AR DIGITAL',
+  FM => 'FAC REGISTRADO (MONITORADO)',
   FR => 'FAC REGISTRADO',
-  IA => 'LOGÍSTICA INTEGRADA (AGENDADO/AVULSO)',
-  IC => 'LOGÍSTICA INTEGRADA (A COBRAR)',
-  ID => 'LOGÍSTICA INTEGRADA (DEVOLUCAO DE DOCUMENTO)',
-  IE => 'LOGÍSTICA INTEGRADA (ESPECIAL)',
+  IA => 'INTEGRADA AVULSA',
+  IC => 'INTEGRADA A COBRAR',
+  ID => 'INTEGRADA DEVOLUCAO DE DOCUMENTO',
+  IE => 'INTEGRADA ESPECIAL',
   IF => 'CPF',
-  II => 'LOGÍSTICA INTEGRADA (ECT)',
-  IK => 'LOGÍSTICA INTEGRADA COM COLETA SIMULTÂNEA',
-  IM => 'LOGÍSTICA INTEGRADA (MEDICAMENTOS)',
-  IN => 'CORRESPONDÊNCIA E EMS RECEBIDO DO EXTERIOR',
-  IP => 'LOGÍSTICA INTEGRADA (PROGRAMADA)',
+  II => 'INTEGRADA INTERNO',
+  IK => 'INTEGRADA COM COLETA SIMULTANEA',
+  IM => 'INTEGRADA MEDICAMENTOS',
+  IN => 'OBJETO DE CORRESP E EMS REC EXTERIOR',
+  IP => 'INTEGRADA PROGRAMADA',
   IR => 'IMPRESSO REGISTRADO',
-  IS => 'LOGÍSTICA INTEGRADA STANDARD (MEDICAMENTOS)',
-  IT => 'REMESSA EXPRESSA MEDICAMENTOS / LOGÍSTICA INTEGRADA TERMOLÁBIL',
-  IU => 'LOGÍSTICA INTEGRADA (URGENTE)',
-  IX => 'EDEI EXPRESSO',
+  IS => 'INTEGRADA STANDARD',
+  IT => 'INTEGRADA TERMOLABIL',
+  IU => 'INTEGRADA URGENTE',
+  IX => 'EDEI ENCOMENDA EXPRESSA',
   JA => 'REMESSA ECONOMICA COM AR DIGITAL',
   JB => 'REMESSA ECONOMICA COM AR DIGITAL',
   JC => 'REMESSA ECONOMICA COM AR DIGITAL',
-  JD => 'REMESSA ECONOMICA TALÃO/CARTÃO',
-  JE => 'REMESSA ECONÔMICA COM AR DIGITAL',
-  JF => 'REMESSA ECONÔMICA COM AR DIGITAL',
-  JG => 'OBJETO REGISTRADO URGENTE/PRIORITÁRIO',
-  JH => 'OBJETO REGISTRADO URGENTE/PRIORITÁRIO',
-  JI => 'REMESSA ECONÔMICA TALÃO/CARTÃO',
-  JJ => 'OBJETO REGISTRADO (JUSTIÇA)',
-  JK => 'REMESSA ECONÔMICA TALÃO/CARTÃO',
-  JL => 'OBJETO REGISTRADO',
+  JD => 'REMESSA ECONOMICA SEM AR DIGITAL',
+  JE => 'REMESSA ECONOMICA COM AR DIGITAL',
+  JF => 'REMESSA ECONOMICA COM AR DIGITAL',
+  JG => 'REGISTRADO PRIORITARIO',
+  JH => 'REGISTRADO PRIORITARIO',
+  JI => 'REMESSA ECONOMICA SEM AR DIGITAL',
+  JJ => 'REGISTRADO JUSTICA',
+  JK => 'REMESSA ECONOMICA SEM AR DIGITAL',
+  JL => 'REGISTRADO LOGICO',
   JM => 'MALA DIRETA POSTAL ESPECIAL',
-  JN => 'OBJETO REGISTRADO ECONÔMICO',
-  JO => 'OBJETO REGISTRADO URGENTE',
-  JP => 'RECEITA FEDERAL',
-  JQ => 'REMESSA ECONÔMICA COM AR DIGITAL',
-  JR => 'OBJETO REGISTRADO URGENTE/PRIORITÁRIO',
-  JS => 'OBJETO REGISTRADO',
-  JT => 'OBJETO REGISTRADO URGENTE',
-  JV => 'REMESSA ECONÔMICA COM AR DIGITAL',
-  LA => 'SEDEX COM LOGÍSTICA REVERSA SIMULTÂNEA EM AGÊNCIA',
-  LB => 'E-SEDEX COM LOGÍSTICA REVERSA SIMULTÂNEA EM AGÊNCIA',
-  LC => 'OBJETO INTERNACIONAL (PRIME)',
-  LE => 'LOGÍSTICA REVERSA ECONOMICA',
-  LF => 'OBJETO INTERNACIONAL (PRIME)',
-  LI => 'OBJETO INTERNACIONAL (PRIME)',
-  LJ => 'OBJETO INTERNACIONAL (PRIME)',
-  LK => 'OBJETO INTERNACIONAL (PRIME)',
-  LM => 'OBJETO INTERNACIONAL (PRIME)',
-  LN => 'OBJETO INTERNACIONAL (PRIME)',
-  LP => 'PAC COM LOGÍSTICA REVERSA SIMULTÂNEA EM AGÊNCIA',
-  LS => 'SEDEX LOGISTICA REVERSA',
+  JN => 'MALA DIRETA POSTAL ESPECIAL',
+  JO => 'REGISTRADO PRIORITARIO',
+  JP => 'OBJETO RECEITA FEDERAL (EXCLUSIVO)',
+  JQ => 'REMESSA ECONOMICA COM AR DIGITAL',
+  JR => 'REGISTRADO PRIORITARIO',
+  JS => 'REGISTRADO LOGICO',
+  JT => 'REGISTRADO URGENTE',
+  JU => 'ETIQUETA FISICA REGISTRADO URGENTE',
+  JV => 'REMESSA ECONOMICA COM AR DIGITAL',
+  JW => 'CARTA COMERCIAL A FATURAR (5 DIAS)',
+  JX => 'CARTA COMERCIAL A FATURAR (10 DIAS)',
+  JY => 'REMESSA ECONOMICA (5 DIAS)',
+  JZ => 'REMESSA ECONOMICA (10 DIAS)',
+  LA => 'LOGISTICA REVERSA SIMULTANEA SEDEX',
+  LB => 'LOGISTICA REVERSA SIMULTANEA SEDEX',
+  LC => 'OBJETO INTERNACIONAL PRIME',
+  LD => 'OBJETO INTERNACIONAL PRIME',
+  LE => 'LOGISTICA REVERSA ECONOMICA',
+  LF => 'OBJETO INTERNACIONAL PRIME',
+  LG => 'OBJETO INTERNACIONAL PRIME',
+  LH => 'OBJETO INTERNACIONAL PRIME',
+  LI => 'OBJETO INTERNACIONAL PRIME',
+  LJ => 'OBJETO INTERNACIONAL PRIME',
+  LK => 'OBJETO INTERNACIONAL PRIME',
+  LL => 'OBJETO INTERNACIONAL PRIME',
+  LM => 'OBJETO INTERNACIONAL PRIME',
+  LN => 'OBJETO INTERNACIONAL PRIME',
+  LP => 'LOGISTICA REVERSA SIMULTANEA PAC',
+  LQ => 'OBJETO INTERNACIONAL PRIME',
+  LS => 'LOGISTICA REVERSA SEDEX',
   LV => 'LOGISTICA REVERSA EXPRESSA',
-  LX => 'PACKET STANDARD/ECONÔMICA',
-  LZ => 'OBJETO INTERNACIONAL (PRIME)',
-  MA => 'SERVIÇOS ADICIONAIS DO TELEGRAMA',
-  MB => 'TELEGRAMA (BALCÃO)',
-  MC => 'TELEGRAMA (FONADO)',
-  MD => 'SEDEX MUNDI (DOCUMENTO INTERNO)',
+  LW => 'OBJETO INTERNACIONAL PRIME',
+  LX => 'OBJETO INTERNACIONAL PACKET ECONOMIC',
+  LY => 'OBJETO INTERNACIONAL PRIME',
+  LZ => 'OBJETO INTERNACIONAL PRIME',
+  MA => 'TELEGRAMA - SERVICOS ADICIONAIS',
+  MB => 'TELEGRAMA DE BALCAO',
+  MC => 'TELEGRAMA FONADO',
+  MD => 'MAQUINA DE FRANQUEAR (LOGICA)',
   ME => 'TELEGRAMA',
   MF => 'TELEGRAMA FONADO',
-  MK => 'TELEGRAMA (CORPORATIVO)',
-  ML => 'FECHA MALAS (RABICHO)',
-  MM => 'TELEGRAMA (GRANDES CLIENTES)',
-  MP => 'TELEGRAMA (PRÉ-PAGO)',
-  MR => 'AR DIGITAL',
+  MH => 'CARTA VIA INTERNET',
+  MK => 'TELEGRAMA CORPORATIVO',
+#  ML => 'FECHA MALAS (RABICHO)', # <-- descontinuado? (sumiu da lista oficial)
+  MM => 'TELEGRAMA GRANDES CLIENTES',
+  MP => 'TELEGRAMA PRE-PAGO',
+#  MR => 'AR DIGITAL', # <-- descontinuado? (sumiu da lista oficial)
   MS => 'ENCOMENDA SAUDE',
-  MT => 'TELEGRAMA (TELEMAIL)',
-  MY => 'TELEGRAMA INTERNACIONAL (ENTRANTE)',
-  MZ => 'TELEGRAMA (CORREIOS ONLINE)',
+  MT => 'TELEGRAMA VIA TELEMAIL',
+  MY => 'TELEGRAMA INTERNACIONAL ENTRANTE',
+  MZ => 'TELEGRAMA VIA CORREIOS ONLINE',
   NE => 'TELE SENA RESGATADA',
-  NX => 'EDEI ECONÔMICO (NÃO URGENTE)',
-  OA => 'ENCOMENDA SEDEX',
-  OB => 'ENCOMENDA E-SEDEX',
+  NX => 'EDEI ENCOMENDA NAO URGENTE',
+  OA => 'ENCOMENDA SEDEX (ETIQUETA LOGICA)',
+  OB => 'ENCOMENDA SEDEX (ETIQUETA LOGICA)',
+  OC => 'ENCOMENDA SEDEX (ETIQUETA LOGICA)',
+  OD => 'ENCOMENDA SEDEX (ETIQUETA FISICA)',
   PA => 'PASSAPORTE',
-  PB => 'PAC',
-  PC => 'PAC A COBRAR',
-  PD => 'PAC',
-  PE => 'PAC',
+  PB => 'ENCOMENDA PAC - NAO URGENTE',
+  PC => 'ENCOMENDA PAC A COBRAR',
+  PD => 'ENCOMENDA PAC',
+  PE => 'ENCOMENDA PAC (ETIQUETA FISICA)',
   PF => 'PASSAPORTE',
-  PG => 'PAC',
-  PH => 'PAC',
-  PI => 'PAC',
-  PJ => 'PAC',
+  PG => 'ENCOMENDA PAC (ETIQUETA FISICA)',
+  PH => 'ENCOMENDA PAC (ETIQUETA LOGICA)',
+  PI => 'ENCOMENDA PAC',
+  PJ => 'ENCOMENDA PAC',
   PK => 'PAC EXTRA GRANDE',
-  PL => 'PAC',
-  PN => 'PAC',
-  PR => 'REEMBOLSO POSTAL',
-  QQ => 'OBJETO DE TESTE (SIGEP WEB)',
-  RA => 'OBJETO REGISTRADO/PRIORITÁRIO',
+  PL => 'ENCOMENDA PAC',
+  PM => 'ENCOMENDA PAC (ETIQUETA FISICA)',
+  PN => 'ENCOMENDA PAC (ETIQUETA LOGICA)',
+  PO => 'ENCOMENDA PAC (ETIQUETA LOGICA)',
+  PP => 'ETIQUETA LOGICA PAC',
+  PR => 'REEMBOLSO POSTAL - CLIENTE AVULSO',
+#  QQ => 'OBJETO DE TESTE (SIGEP WEB)', # <-- descontinuado? (sumiu da lista oficial)
+  RA => 'REGISTRADO PRIORITARIO',
   RB => 'CARTA REGISTRADA',
   RC => 'CARTA REGISTRADA COM VALOR DECLARADO',
-  RD => 'REMESSA ECONOMICA OU OBJETO REGISTRADO (DETRAN)',
-  RE => 'OBJETO REGISTRADO ECONÔMICO',
-  RF => 'RECEITA FEDERAL',
-  RG => 'OBJETO REGISTRADO',
-  RH => 'OBJETO REGISTRADO COM AR DIGITAL',
-  RI => 'OBJETO REGISTRADO INTERNACIONAL PRIORITÁRIO',
-  RJ => 'OBJETO REGISTRADO',
-  RK => 'OBJETO REGISTRADO',
-  RL => 'OBJETO REGISTRADO',
-  RM => 'OBJETO REGISTRADO URGENTE',
-  RN => 'OBJETO REGISTRADO (SIGEPWEB OU AGÊNCIA)',
-  RO => 'OBJETO REGISTRADO',
-  RP => 'REEMBOLSO POSTAL',
-  RQ => 'OBJETO REGISTRADO',
-  RR => 'OBJETO REGISTRADO',
-  RS => 'OBJETO REGISTRADO',
-  RT => 'REMESSA ECONÔMICA TALÃO/CARTAO',
-  RU => 'OBJETO REGISTRADO (ECT)',
-  RV => 'REMESSA ECONÔMICA CRLV/CRV/CNH E NOTIFICAÇÕES COM AR DIGITAL',
-  RW => 'OBJETO INTERNACIONAL',
-  RX => 'OBJETO INTERNACIONAL',
-  RY => 'REMESSA ECONÔMICA TALÃO/CARTÃO COM AR DIGITAL',
-  RZ => 'OBJETO REGISTRADO',
-  SA => 'SEDEX',
+  RD => 'REMESSA ECONOMICA DETRAN',
+  RE => 'MALA DIRETA POSTAL ESPECIAL',
+  RF => 'OBJETO DA RECEITA FEDERAL',
+  RG => 'REGISTRADO DO SISTEMA SARA',
+  RH => 'REGISTRADO COM AR DIGITAL',
+  RI => 'REGISTRADO PRIORITARIO INTERNACIONAL',
+  RJ => 'REGISTRADO AGENCIA',
+  RK => 'REGISTRADO AGENCIA',
+  RL => 'REGISTRADO LOGICO',
+  RM => 'REGISTRADO AGENCIA',
+  RN => 'REGISTRADO AGENCIA',
+  RO => 'REGISTRADO AGENCIA',
+  RP => 'REEMBOLSO POSTAL - CLIENTE INSCRITO',
+  RQ => 'REGISTRADO AGENCIA',
+  RR => 'REGISTRADO INTERNACIONAL',
+  RS => 'REMESSA ECONOMICA ORG TRANSITO COM OU SEM AR',
+  RT => 'REMESSA ECONOMICA TALAO/CARTAO SEM AR DIGITAL',
+  RU => 'REGISTRADO SERVICO ECT',
+  RV => 'REMESSA ECONOMICA CRLV/CRV/CNH COM AR DIGITAL',
+  RW => 'REGISTRADO INTERNACIONAL',
+  RX => 'REGISTRADO INTERNACIONAL',
+  RY => 'REMESSA ECONOMICA TALAO/CARTAO COM AR DIGITAL',
+  RZ => 'REGISTRADO',
+  SA => 'ETIQUETA SEDEX AGENCIA',
   SB => 'SEDEX 10',
   SC => 'SEDEX A COBRAR',
-  SD => 'SEDEX OU REMESSA EXPRESSA (DETRAN)',
-  SE => 'SEDEX',
-  SF => 'SEDEX',
-  SG => 'SEDEX',
-  SH => 'SEDEX COM AR DIGITAL / SEDEX OU AR DIGITAL',
-  SI => 'SEDEX',
+  SD => 'REMESSA EXPRESSA DETRAN',
+  SE => 'ENCOMENDA SEDEX',
+  SF => 'SEDEX AGENCIA',
+  SG => 'SEDEX DO SISTEMA SARA',
+  SH => 'SEDEX COM AR DIGITAL',
+  SI => 'SEDEX AGENCIA',
   SJ => 'SEDEX HOJE',
-  SK => 'SEDEX',
-  SL => 'SEDEX',
+  SK => 'SEDEX AGENCIA',
+  SL => 'SEDEX LOGICO',
   SM => 'SEDEX 12',
-  SN => 'SEDEX',
-  SO => 'SEDEX',
-  SP => 'SEDEX PRÉ-FRANQUEADO',
+  SN => 'SEDEX AGENCIA',
+  SO => 'SEDEX AGENCIA',
+  SP => 'SEDEX PRE-FRANQUEADO',
   SQ => 'SEDEX',
   SR => 'SEDEX',
-  SS => 'SEDEX',
-  ST => 'REMESSA EXPRESSA TALÃO/CARTÃO',
-  SU => 'ENCOMENDA DE SERVIÇO EXPRESSA (ECT)',
-  SV => 'REMESSA EXPRESSA CRLV/CRV/CNH E NOTIFICAÇÕES COM AR DIGITAL',
-  SW => 'E-SEDEX',
+  SS => 'SEDEX FISICO',
+  ST => 'REMESSA EXPRESSA TALAO/CARTAO SEM AR DIGITAL',
+  SU => 'ENCOMENDA SERVICO EXPRESSA ECT',
+  SV => 'REMESSA EXPRESSA CRLV/CRV/CNH COM AR DIGITAL',
+  SW => 'ENCOMENDA SEDEX',
   SX => 'SEDEX 10',
-  SY => 'REMESSA EXPRESSA TALÃO/CARTÃO COM AR DIGITAL',
-  SZ => 'SEDEX',
-  TC => 'OBJETO PARA TREINAMENTO',
-  TE => 'OBJETO PARA TREINAMENTO',
-  TS => 'OBJETO PARA TREINAMENTO',
-  VA => 'ENCOMENDAS COM VALOR DECLARADO',
-  VC => 'ENCOMENDAS',
-  VD => 'ENCOMENDAS COM VALOR DECLARADO',
-  VE => 'ENCOMENDAS',
-  VF => 'ENCOMENDAS COM VALOR DECLARADO',
-  VV => 'OBJETO INTERNACIONAL',
-  XA => 'AVISO DE CHEGADA (INTERNACIONAL)',
+  SY => 'REMESSA EXPRESSA TALAO/CARTAO COM AR DIGITAL',
+  SZ => 'SEDEX AGENCIA',
+  TC => 'TESTE (OBJETO PARA TREINAMENTO)',
+  TE => 'TESTE (OBJETO PARA TREINAMENTO)',
+  TR => 'OBJETO TREINAMENTO - NAO GERA PRE-ALERTA',
+  TS => 'TESTE (OBJETO PARA TREINAMENTO)',
+  VA => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  VC => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  VD => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  VE => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  VF => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  VV => 'OBJETO INTERNACIONAL COM VALOR DECLARADO',
+  XA => 'AVISO DE CHEGADA OBJETO INTERNACIONAL TRIBUTADO',
   XM => 'SEDEX MUNDI',
-  XR => 'ENCOMENDA SUR POSTAL EXPRESSO',
-  XX => 'ENCOMENDA SUR POSTAL 24 HORAS',
+  XR => 'OBJETO INTERNACIONAL (PPS TRIBUTADO)',
+  XX => 'OBJETO INTERNACIONAL (PPS TRIBUTADO)',
 );
 
 # http://www.correios.com.br/para-sua-empresa/servicos-para-o-seu-contrato/guias/enderecamento/arquivos/guia_tecnico_encomendas.pdf/at_download/file
@@ -465,7 +494,7 @@ API em português:
 
     return 'SRO inválido' unless sro_ok( $codigo );
 
-    my $prefixo = sro_sigla( $codigo ); # retorna "SEDEX";
+    my $prefixo = sro_sigla( $codigo ); # retorna "SEDEX FISICO";
 
     my @historico_completo = sro( $codigo );
 
@@ -475,7 +504,7 @@ API em português:
     {
         cidade    => "BELO HORIZONTE",
         codigo    => 31276970,
-        data      => "19/05/2017",
+        data      => "19/03/2018",
         descricao => "Objeto encaminhado",
         destino   => {
             bairro => "Parque Novo Mundo",
